/****************************************************************************
** Meta object code from reading C++ file 'newattachment.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../drkonqi-6.7.2/src/bugzillaintegration/libbugzilla/clients/commands/newattachment.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'newattachment.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Bugzilla13NewAttachmentE_t {};
} // unnamed namespace

template <> constexpr inline auto Bugzilla::NewAttachment::qt_create_metaobjectdata<qt_meta_tag_ZN8Bugzilla13NewAttachmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Bugzilla::NewAttachment",
        "ids",
        "QList<int>",
        "data",
        "file_name",
        "summary",
        "content_type",
        "comment",
        "is_patch",
        "is_private"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ids'
        QtMocHelpers::PropertyData<QList<int>>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'data'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'file_name'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'summary'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'content_type'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'comment'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'is_patch'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'is_private'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NewAttachment, qt_meta_tag_ZN8Bugzilla13NewAttachmentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Bugzilla::NewAttachment::staticMetaObject = { {
    QMetaObject::SuperData::link<JsonCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla13NewAttachmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla13NewAttachmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Bugzilla13NewAttachmentE_t>.metaTypes,
    nullptr
} };

void Bugzilla::NewAttachment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NewAttachment *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<int>*>(_v) = _t->ids; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->data; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->file_name; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->summary; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->content_type; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->comment; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->is_patch; break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->is_private; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->ids, *reinterpret_cast<QList<int>*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->data, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->file_name, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->summary, *reinterpret_cast<QString*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->content_type, *reinterpret_cast<QString*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->comment, *reinterpret_cast<QString*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->is_patch, *reinterpret_cast<bool*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->is_private, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Bugzilla::NewAttachment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Bugzilla::NewAttachment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla13NewAttachmentE_t>.strings))
        return static_cast<void*>(this);
    return JsonCommand::qt_metacast(_clname);
}

int Bugzilla::NewAttachment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = JsonCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
