/****************************************************************************
** Meta object code from reading C++ file 'backtraceparser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../drkonqi-6.7.2/src/parser/backtraceparser.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'backtraceparser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15BacktraceParserE_t {};
} // unnamed namespace

template <> constexpr inline auto BacktraceParser::qt_create_metaobjectdata<qt_meta_tag_ZN15BacktraceParserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BacktraceParser",
        "resetState",
        "",
        "newLineInternal",
        "lineStr",
        "newLine",
        "backtraceUsefulness",
        "BacktraceParser::Usefulness",
        "librariesWithMissingDebugSymbols",
        "Usefulness",
        "InvalidUsefulness",
        "Useless",
        "ProbablyUseless",
        "MayBeUseful",
        "ReallyUseful"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'resetState'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newLineInternal'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'newLine'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'backtraceUsefulness'
        QtMocHelpers::MethodData<BacktraceParser::Usefulness() const>(6, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Method 'librariesWithMissingDebugSymbols'
        QtMocHelpers::MethodData<QStringList() const>(8, 2, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Usefulness'
        QtMocHelpers::EnumData<enum Usefulness>(9, 9, QMC::EnumFlags{}).add({
            {   10, Usefulness::InvalidUsefulness },
            {   11, Usefulness::Useless },
            {   12, Usefulness::ProbablyUseless },
            {   13, Usefulness::MayBeUseful },
            {   14, Usefulness::ReallyUseful },
        }),
    };
    return QtMocHelpers::metaObjectData<BacktraceParser, qt_meta_tag_ZN15BacktraceParserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BacktraceParser::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BacktraceParserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BacktraceParserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15BacktraceParserE_t>.metaTypes,
    nullptr
} };

void BacktraceParser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BacktraceParser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resetState(); break;
        case 1: _t->newLineInternal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->newLine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: { BacktraceParser::Usefulness _r = _t->backtraceUsefulness();
            if (_a[0]) *reinterpret_cast<BacktraceParser::Usefulness*>(_a[0]) = std::move(_r); }  break;
        case 4: { QStringList _r = _t->librariesWithMissingDebugSymbols();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *BacktraceParser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BacktraceParser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BacktraceParserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BacktraceParser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
